pm4py.algo.conformance.alignments.process\_tree package
=======================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.process_tree.util
   pm4py.algo.conformance.alignments.process_tree.variants

Submodules
----------

pm4py.algo.conformance.alignments.process\_tree.algorithm module
----------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree
   :members:
   :undoc-members:
   :show-inheritance:
